grafanarmadillo
===============

.. automodule:: grafanarmadillo
    :members:


Find
----

.. automodule:: grafanarmadillo.find
    :members:

Dashboarder
-----------

.. automodule:: grafanarmadillo.dashboarder
    :members:

Templator
---------

.. automodule:: grafanarmadillo.templator
    :members:
